Package: scTHI
Title: Indentification of significantly activated ligand-receptor
        interactions across clusters of cells from single-cell RNA
        sequencing data
Version: 1.24.0
Authors@R: c(person("Francesca Pia", "Caruso", email = "francescapia.caruso@gmail.com", role = c("aut")),
	person("Michele", "Ceccarelli", email = "m.ceccarelli@gmail.com", role = c("aut", "cre")))
Description: scTHI is an R package to identify active pairs of ligand-receptors from single cells in order to study,among others, tumor-host interactions. scTHI contains a set of signatures to classify cells from the tumor microenvironment.
Depends: R (>= 4.0)
License: GPL-2
Encoding: UTF-8
RoxygenNote: 6.1.1.9000
Imports: BiocParallel, Rtsne, grDevices, graphics, stats
Suggests: scTHI.data, knitr, rmarkdown, BiocStyle
VignetteBuilder: knitr
biocViews: Software,SingleCell
BugReports: https://github.com/miccec/scTHI/issues
git_url: https://git.bioconductor.org/packages/scTHI
git_branch: RELEASE_3_23
git_last_commit: c376b19
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:36:15 UTC; biocbuild
Author: Francesca Pia Caruso [aut],
  Michele Ceccarelli [aut, cre]
Maintainer: Michele Ceccarelli <m.ceccarelli@gmail.com>
