# Generated by roxygen2: do not edit by hand

export(TME_classification)
export(TME_plot)
export(scTHI_plotCluster)
export(scTHI_plotPairs)
export(scTHI_plotResult)
export(scTHI_runTsne)
export(scTHI_score)
importFrom(BiocParallel,SnowParam)
importFrom(BiocParallel,bplapply)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,hcl)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,text)
importFrom(stats,density)
importFrom(stats,p.adjust)
importFrom(stats,pnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
