#' @importFrom grDevices colorRampPalette hcl
#' @importFrom graphics barplot legend par plot text
#' @importFrom stats density p.adjust quantile sd pnorm
#' @importFrom BiocParallel SnowParam bplapply
NULL